==> v2.0.12-cawlop.zip: cawlop/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.12] - 2025-14-10
### Added
- Add compatibility with PrestaShop 9
- Add masking for API credentials
- Fix showing Mealvouchers on hosted checkout
- Fix DB transaction caching
- Fix uninstall error

## [2.0.11] - 2025-28-08
### Added
- Add configuration to send webhook url in payloads

## [2.0.10] - 2025-22-08
### Changed
- Fix wrong shipping calculation upon clicking back and changing shipping carrier

## [2.0.9] - 2025-13-08
### Added
- Add null checking in liability/exemption chain

## [2.0.8] - 2025-11-08
### Added
- Add missing translations

## [2.0.7] - 2025-24-07
### Added
- Remove extension validation for template filename
- Implement omit order item details button and logic
- Fix order total webhook issue

## [2.0.6] - 2025-01-07
### Added
- Implement new payment method : Mealvouchers
- Implement new payment method : Chèque-Vacances Connect (CVCO)

## [2.0.5] - 2025-22-05
### Added
- Add compatibility with PrestaShop 8.2

## [2.0.4] - 2025-24-04
### Changed
- Update plugin translations

## [2.0.3] - 2025-31-03
### Added
- Add 3DS exemption types to the plugin

## [2.0.2] - 2025-21-03
### Changed
- Fix issue with submit button not being deactivated when card fields are not added on checkout

## [2.0.1] - 2025-25-02
### Changed
- Update payment gateway API base URL

## [2.0.0] - 2024-27-12
### Added

- Add compliance with PS 8
- Always return a 200 response to a webhook call

### Changed
- Update WebhookEventPresenter

### Fixed

- Fix amounts inside capture & refund blocks
- Fix ProductsType empty
- Fix fraud display
- Fix amount verification
- Fix lock in processor

==> v2.0.18-cawlop.zip: cawlop/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.18] - 2025-22-12
### Added
- Group same items in shoppingCart details
- Fix error when retrieving transaction details on order details page

## [2.0.17] - 2025-05-12
### Added
- Manage exemption for FR markets

## [2.0.16] - 2025-02-12
### Added
- Add new payment method : Pledg
### Fixed
- Fix iFrame rendering on mobile phones
- Fix order total not being updated when customer adds or removes gift wrapping
- Change tokenizer preproduction URL to production

## [2.0.15] - 2025-14-11
### Fixed
- Fix being able to delete default logo when upgrading from earlier version

## [2.0.14] - 2025-13-11
### Added
- Add reverting to default logo in payment methods settings page

## [2.0.13] - 2025-30-10
### Changed
- Update configuration guidelines
- Fix transaction operations having wrong status
- Fix wrong price being recorded in database when non-default currency is used on checkout 
- Fix secret fields not being masked when wrong webhook key is entered

## [2.0.12] - 2025-14-10
### Added
- Add compatibility with PrestaShop 9
- Add masking for API credentials
- Fix showing Mealvouchers on hosted checkout
- Fix DB transaction caching
- Fix uninstall error

## [2.0.11] - 2025-28-08
### Added
- Add configuration to send webhook url in payloads

## [2.0.10] - 2025-22-08
### Changed
- Fix wrong shipping calculation upon clicking back and changing shipping carrier

## [2.0.9] - 2025-13-08
### Added
- Add null checking in liability/exemption chain

## [2.0.8] - 2025-11-08
### Added
- Add missing translations

## [2.0.7] - 2025-24-07
### Added
- Remove extension validation for template filename
- Implement omit order item details button and logic
- Fix order total webhook issue

## [2.0.6] - 2025-01-07
### Added
- Implement new payment method : Mealvouchers
- Implement new payment method : Chèque-Vacances Connect (CVCO)

## [2.0.5] - 2025-22-05
### Added
- Add compatibility with PrestaShop 8.2

## [2.0.4] - 2025-24-04
### Changed
- Update plugin translations

## [2.0.3] - 2025-31-03
### Added
- Add 3DS exemption types to the plugin

## [2.0.2] - 2025-21-03
### Changed
- Fix issue with submit button not being deactivated when card fields are not added on checkout

## [2.0.1] - 2025-25-02
### Changed
- Update payment gateway API base URL

## [2.0.0] - 2024-27-12
### Added

- Add compliance with PS 8
- Always return a 200 response to a webhook call

### Changed
- Update WebhookEventPresenter

### Fixed

- Fix amounts inside capture & refund blocks
- Fix ProductsType empty
- Fix fraud display
- Fix amount verification
- Fix lock in processor
